package api

import (
	"errors"
	"net/http"

	"google.golang.org/grpc/codes"
	"google.golang.org/grpc/status"
)

var (
	ErrBadRequest = errors.New("bad request")
	ErrNotFound   = errors.New("not found")
	ErrConflict   = errors.New("conflict")
)

func ErrToStatus(err error) int {
	// If the error is a gRPC error, we can extract the status code.
	if status, ok := status.FromError(err); ok {
		switch status.Code() {
		case codes.InvalidArgument:
			return http.StatusBadRequest
		case codes.AlreadyExists:
			return http.StatusConflict
		case codes.Unavailable:
			return http.StatusServiceUnavailable
		}
	}

	if errors.Is(err, ErrBadRequest) {
		return http.StatusBadRequest
	}
	if errors.Is(err, ErrNotFound) {
		return http.StatusNotFound
	}

	if errors.Is(err, ErrConflict) {
		return http.StatusConflict
	}

	// Default error to return
	return http.StatusInternalServerError
}
